#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: semigroupoids
version: 5.2.1
id: semigroupoids-5.2.1-159o3FQm8wLAkIaxuoQCLq
key: semigroupoids-5.2.1-159o3FQm8wLAkIaxuoQCLq
license: BSD3
copyright: Copyright (C) 2011-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/semigroupoids
synopsis: Semigroupoids: Category sans id
description:
    Provides a wide array of (semi)groupoids and operations for working with them.
    .
    A '\''Semigroupoid'\'' is a '\''Category'\'' without the requirement of identity arrows for every object in the category.
    .
    A '\''Category'\'' is any '\''Semigroupoid'\'' for which the Yoneda lemma holds.
    .
    When working with comonads you often have the @\<*\>@ portion of an @Applicative@, but
    not the @pure@. This was captured in Uustalu and Vene'\''s \"Essence of Dataflow Programming\"
    in the form of the @ComonadZip@ class in the days before @Applicative@. Apply provides a weaker invariant, but for the comonads used for data flow programming (found in the streams package), this invariant is preserved. Applicative function composition forms a semigroupoid.
    .
    Similarly many structures are nearly a comonad, but not quite, for instance lists provide a reasonable '\''extend'\'' operation in the form of '\''tails'\'', but do not always contain a value.
    .
    Ideally the following relationships would hold:
    .
    > Foldable ----> Traversable <--- Functor ------> Alt ---------> Plus           Semigroupoid
    >      |               |            |                              |                  |
    >      v               v            v                              v                  v
    > Foldable1 ---> Traversable1     Apply --------> Applicative -> Alternative      Category
    >                                   |               |              |                  |
    >                                   v               v              v                  v
    >                                 Bind ---------> Monad -------> MonadPlus          Arrow
    >
    .
    Apply, Bind, and Extend (not shown) give rise the Static, Kleisli and Cokleisli semigroupoids respectively.
    .
    This lets us remove many of the restrictions from various monad transformers
    as in many cases the binding operation or @\<*\>@ operation does not require them.
    .
    Finally, to work with these weaker structures it is beneficial to have containers
    that can provide stronger guarantees about their contents, so versions of '\''Traversable'\''
    and '\''Foldable'\'' that can be folded with just a '\''Semigroup'\'' are added.
category: Control, Comonads
author: Edward A. Kmett
exposed: True
indefinite: False
exposed-modules:
    Data.Bifunctor.Apply Data.Functor.Alt Data.Functor.Apply
    Data.Functor.Bind Data.Functor.Bind.Class Data.Functor.Bind.Trans
    Data.Functor.Extend Data.Functor.Plus Data.Groupoid
    Data.Isomorphism Data.Semigroup.Bifoldable
    Data.Semigroup.Bitraversable Data.Semigroup.Foldable
    Data.Semigroup.Foldable.Class Data.Semigroup.Traversable
    Data.Semigroup.Traversable.Class Data.Semigroupoid
    Data.Semigroupoid.Dual Data.Semigroupoid.Ob
    Data.Semigroupoid.Static Data.Traversable.Instances
abi: b68b1907ab7e61c87589c79096b0d5d2
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/semigroupoids-5.2.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/semigroupoids-5.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/semigroupoids-5.2.1
hs-libraries: HSsemigroupoids-5.2.1-159o3FQm8wLAkIaxuoQCLq
depends:
    base-4.10.1.0 base-orphans-0.6-KoJqNefbvUAEuaR7CDOiu4
    bifunctors-5.4.2-Cctfp3LopdNGpYrwymp5RT
    semigroups-0.18.3-3aCIuYG4ID286XaN6MuQu7 transformers-0.5.2.0
    transformers-compat-0.5.1.4-EAh8Ccrgitz4vTZtbTPyCM
    containers-0.5.10.2 contravariant-1.4-7z11WOqE85DGeP9JdLBkE1
    distributive-0.5.3-3QQWO3yfOScASLf5zUz2JE
    comonad-5.0.2-5FGZALTgAAwCV8EmXasfw1
    tagged-0.8.5-BP06XmR1GLaIsvsOKwGst2
    hashable-1.2.6.1-9ZXmUmZR8Ja1wkFjzrwxTy
    unordered-containers-0.2.8.0-I4wGGMV7X9X97sk1hrOqCV
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             base-orphans-0.6-KoJqNefbvUAEuaR7CDOiu4=fb09ffe63c021a5df200f5dd3f288699
             bifunctors-5.4.2-Cctfp3LopdNGpYrwymp5RT=fb2e1f6c564aaaf15a6b3dad27d803af
             semigroups-0.18.3-3aCIuYG4ID286XaN6MuQu7=d64b81e3ed8022aca04423ee7b330679
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             transformers-compat-0.5.1.4-EAh8Ccrgitz4vTZtbTPyCM=506de314acc216de1ce76634db1785eb
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             contravariant-1.4-7z11WOqE85DGeP9JdLBkE1=229249a7c431fe44ea9abf1ace1931a4
             distributive-0.5.3-3QQWO3yfOScASLf5zUz2JE=4194008627baa63a29bcee90329e8d22
             comonad-5.0.2-5FGZALTgAAwCV8EmXasfw1=c9494ddd8dca169177efbeae2d54ce78
             tagged-0.8.5-BP06XmR1GLaIsvsOKwGst2=b5d07becd47ba21e20b584b61ad0f06d
             hashable-1.2.6.1-9ZXmUmZR8Ja1wkFjzrwxTy=6e4b4a70e10d525b7db51e3859aab169
             unordered-containers-0.2.8.0-I4wGGMV7X9X97sk1hrOqCV=db9131d5548eea6d7a3eab9f0d172004
haddock-interfaces: /usr/share/doc/haskell-semigroupoids/html/semigroupoids.haddock
haddock-html: /usr/share/doc/haskell-semigroupoids/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

